<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hi">
<context>
    <name>ColorLabel</name>
    <message>
        <location filename="../colorLabel.cpp" line="37"/>
        <source>Click to change color</source>
        <translation>रंग बदलने के लिए क्लिक करें</translation>
    </message>
    <message>
        <location filename="../colorLabel.cpp" line="61"/>
        <source>Select Color</source>
        <translation>रंग चुनें</translation>
    </message>
</context>
<context>
    <name>ConfigOtherToolKits</name>
    <message>
        <location filename="../configothertoolkits.cpp" line="178"/>
        <source>GTK themes</source>
        <translation>जीटीके थीम</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="179"/>
        <source>&lt;p&gt;&apos;%1&apos; has been overwritten.&lt;/p&gt;&lt;p&gt;You can find a copy of your old settings in &apos;%2&apos;&lt;/p&gt;</source>
        <translation>&lt;p&gt;&apos;%1&apos; को अधिलेखित कर दिया गया है.&lt;/p&gt;&lt;p&gt;आप &apos;%2&apos; में अपनी पुरानी सेटिंग्स की एक प्रति प्राप्त कर सकते हैं&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="244"/>
        <source>Error</source>
        <translation>त्रुटि</translation>
    </message>
    <message>
        <location filename="../configothertoolkits.cpp" line="244"/>
        <source>Error: gsettings cannot be run</source>
        <translation>त्रुटि : gsettings को नहीं चलाया जा सकता</translation>
    </message>
</context>
<context>
    <name>FontsConfig</name>
    <message>
        <location filename="../fontsconfig.ui" line="23"/>
        <source>Font</source>
        <translation>फ़ॉन्ट</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="30"/>
        <source>Default font for user interface</source>
        <translation>उपयोगकर्ता इंटरफ़ेस के लिए आरंभिक फ़ॉन्ट</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="36"/>
        <source>Font name:</source>
        <translation>फ़ॉन्ट का नाम :</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="46"/>
        <source>Style:</source>
        <translation>शैली :</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="77"/>
        <source>Point size:</source>
        <translation>Point में आकार :</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="54"/>
        <source>Normal</source>
        <translation>सामान्य</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="59"/>
        <source>Bold</source>
        <translation>मोटा</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="64"/>
        <source>Italic</source>
        <translation>तिरछा</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="69"/>
        <source>Bold Italic</source>
        <translation>मोटा व तिरछा</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="94"/>
        <source>The following settings only affect newly started applications</source>
        <translation>निम्नलिखित सेटिंग्स केवल नए शुरू किए गए अनुप्रयोगों को प्रभावित करती हैं</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="100"/>
        <source>Use antialias fonts</source>
        <translation>एंटीएलियास फॉन्ट का प्रयोग करें</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="153"/>
        <source>Font hinting style:</source>
        <translation>फ़ॉन्ट संकेत की शैली :</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="118"/>
        <location filename="../fontsconfig.ui" line="164"/>
        <source>None</source>
        <translation>कोई नहीं</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="169"/>
        <source>Slight</source>
        <translation>थोड़ा</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="174"/>
        <source>Medium</source>
        <translation>मध्यम</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="179"/>
        <source>Full</source>
        <translation>पूर्ण</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="146"/>
        <source>Font hinting</source>
        <translation>फ़ॉन्ट संकेत</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="187"/>
        <source>Resolution (DPI):</source>
        <translation>रिज़ॉल्यूशन (DPI):</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="204"/>
        <source>Autohint</source>
        <translation>स्वतः संकेत</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="107"/>
        <source>Subpixel antialiasing:</source>
        <translation>उप-पिक्सेल एंटीएलियासिंग :</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="123"/>
        <source>RGB</source>
        <translation>RGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="128"/>
        <source>BGR</source>
        <translation>BGR</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="133"/>
        <source>VRGB</source>
        <translation>VRGB</translation>
    </message>
    <message>
        <location filename="../fontsconfig.ui" line="138"/>
        <source>VBGR</source>
        <translation>VBGR</translation>
    </message>
</context>
<context>
    <name>GTKConfig</name>
    <message>
        <location filename="../gtkconfig.ui" line="44"/>
        <source>GTK Style</source>
        <translation>GTK शैली</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="63"/>
        <source>Set GTK themes (GTK configuration files will be overwritten!)</source>
        <translation>GTK थीम सेट करें (GTK कॉन्फ़िगरेशन फ़ाइलें अधिलेखित हो जाएंगी!)</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="93"/>
        <source>GTK 3 Theme:</source>
        <translation>GTK 3 थीम:</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="77"/>
        <source>GTK 2 Theme:</source>
        <translation>GTK 2 थीम:</translation>
    </message>
    <message>
        <location filename="../gtkconfig.ui" line="105"/>
        <source>To attempt uniform theming, either select similar style/theme (if available) across all lists, or select &apos;gtk2&apos; Qt style (if available) to mimic GTK themes.

Make sure &apos;xsettingsd&apos; is installed to help GTK applications apply themes on the fly.</source>
        <translation>समान थीम का प्रयास करने के लिए, या तो सभी सूचियों में समान शैली/थीम (यदि उपलब्ध हो) का चयन करें, या जीटीके थीम की नकल करने के लिए &apos;gtk2&apos; क्यूटी शैली (यदि उपलब्ध हो) का चयन करें। सुनिश्चित करें कि जीटीके अनुप्रयोगों को तुरंत थीम लागू करने में मदद करने के लिए &apos;xsettingsd&apos; इंस्टॉल किया गया है।</translation>
    </message>
</context>
<context>
    <name>IconThemeConfig</name>
    <message>
        <location filename="../iconthemeconfig.ui" line="14"/>
        <source>LXQt Appearance Configuration</source>
        <translation>LXQt उपस्थिति विन्यास</translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="26"/>
        <source>Icons Theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="87"/>
        <source>The KDE extension of XDG icon themes -&gt; FollowsColorScheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../iconthemeconfig.ui" line="90"/>
        <source>Colorize icons based on widget style (palette)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtThemeConfig</name>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="23"/>
        <source>LXQt Theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="57"/>
        <source>Use wallpaper provided by theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.ui" line="64"/>
        <source>Use palette provided by theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.cpp" line="83"/>
        <source>(User Theme)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtthemeconfig.cpp" line="185"/>
        <source>Open theme folder</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PalettesDialog</name>
    <message>
        <location filename="../palettes.ui" line="14"/>
        <location filename="../palettes.ui" line="20"/>
        <source>Palettes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="33"/>
        <source>Filter...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../palettes.ui" line="43"/>
        <source>&amp;Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>LXQt Appearance Configuration</source>
        <translation type="unfinished">LXQt उपस्थिति विन्यास</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Widget Style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>Icons Theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="92"/>
        <source>LXQt Theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="100"/>
        <source>Font</source>
        <translation type="unfinished">फ़ॉन्ट</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="110"/>
        <source>Cursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="117"/>
        <source>GTK Style</source>
        <translation type="unfinished">GTK शैली</translation>
    </message>
</context>
<context>
    <name>StyleConfig</name>
    <message>
        <location filename="../styleconfig.ui" line="33"/>
        <source>Widget Style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="63"/>
        <source>Qt Palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="77"/>
        <source>Some Qt styles may ignore these colors.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="102"/>
        <source>Window:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="112"/>
        <source>View:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="122"/>
        <source>Selection:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="132"/>
        <source>Tooltip:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="146"/>
        <source>Link:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="166"/>
        <source>Window Text:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="176"/>
        <source>View Text:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="186"/>
        <source>Selected Text:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="196"/>
        <source>Tooltip Text:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="210"/>
        <source>Visited Link:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="242"/>
        <source>&amp;Save Palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="249"/>
        <source>&amp;Load Palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="269"/>
        <source>&amp;Default Palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="284"/>
        <location filename="../styleconfig.ui" line="294"/>
        <location filename="../styleconfig.ui" line="326"/>
        <location filename="../styleconfig.ui" line="336"/>
        <location filename="../styleconfig.ui" line="368"/>
        <source>May be overridden by Qt style or app</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="287"/>
        <source>Toolbar button style:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="298"/>
        <source>Only display the icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="303"/>
        <source>Only display the text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="308"/>
        <source>The text appears beside the icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="313"/>
        <source>The text appears under the icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="318"/>
        <source>Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="329"/>
        <source>Toolbar icon size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="340"/>
        <source>16</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="345"/>
        <source>22</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="350"/>
        <source>24</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="355"/>
        <source>32</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="360"/>
        <source>48</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="371"/>
        <source>Activate item on single click</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.ui" line="51"/>
        <source>Qt Style:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="330"/>
        <location filename="../styleconfig.cpp" line="340"/>
        <source>Save Palette</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="330"/>
        <source>Palette name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="341"/>
        <source>A palette with the same name exists.
Do you want to replace it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="484"/>
        <source>Remove Palettes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../styleconfig.cpp" line="485"/>
        <source>Do you really want to remove selected palette(s)?
Root palettes will remain intact if existing.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
